@@ -1,12 +1,13 @@
-package App::Pinto;
-
 # ABSTRACT: Command-line driver for Pinto
 
+package App::Pinto;
+
 use strict;
 use warnings;
 
+use Encode;
 use Class::Load;
-
+use Term::Prompt;
 use List::Util qw(min);
 use Log::Dispatch::Screen;
 use Log::Dispatch::Screen::Color;
@@ -17,20 +18,20 @@ use App::Cmd::Setup -app;
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub global_opt_spec {
 
     return (
-        [ 'root|r=s'    => 'Path to your repository root directory'  ],
-        [ 'nocolor'     => 'Do not colorize diagnostic messages'     ],
-        [ 'quiet|q'     => 'Only report fatal errors'                ],
-        [ 'verbose|v+'  => 'More diagnostic output (repeatable)'     ],
+        [ 'root|r=s'           => 'Path to your repository root directory'  ],
+        [ 'no-color|no-colour' => 'Do not colorize any output'              ],
+        [ 'password|p=s'       => 'Password for server authentication'      ],
+        [ 'quiet|q'            => 'Only report fatal errors'                ],
+        [ 'username|u=s'       => 'Username for server authentication'      ],
+        [ 'verbose|v+'         => 'More diagnostic output (repeatable)'     ],
     );
-
-    # TODO: Add options for color contols!
 }
 
 #------------------------------------------------------------------------------
@@ -40,16 +41,31 @@ sub pinto {
     my ($self) = @_;
 
     return $self->{pinto} ||= do {
-        my %global_options = %{ $self->global_options() };
+        my $global_options = $self->global_options;
 
-        $global_options{root} ||= $ENV{PINTO_REPOSITORY_ROOT}
-            || $self->usage_error('Must specify a repository root directory');
+        $global_options->{root} ||= $ENV{PINTO_REPOSITORY_ROOT}
+            || $self->usage_error('Must specify a repository root');
 
-        my $pinto_class = $self->pinto_class();
+        $global_options->{password} = $self->_prompt_for_password
+            if defined $global_options->{password} and $global_options->{password} eq '-';
+
+        # Translating (progressive) verbose values into (regressive) log_level values.
+        # Note that we must not pass log_level into the constructor for Pinto, or it
+        # will set the logging level for its own internal logs.
+
+        my $logger_options = {};
+        $logger_options->{log_level} = 3 - min(delete $global_options->{verbose} || 0, 3);
+        $logger_options->{log_level} = 4 if delete $global_options->{quiet};
+        $logger_options->{no_color}  = 1 if delete $global_options->{no_color};
+
+        # TODO: Give helpful error message if the right backend
+        # is not installed.
+
+        my $pinto_class = $self->pinto_class_for($global_options->{root});
         Class::Load::load_class($pinto_class);
 
-        my $pinto = $pinto_class->new(%global_options);
-        $pinto->add_logger($self->logger(%global_options));
+        my $pinto = $pinto_class->new( %{ $global_options } );
+        $pinto->add_logger($self->make_logger( %{ $logger_options } ));
 
         $pinto;
     };
@@ -57,18 +73,22 @@ sub pinto {
 
 #------------------------------------------------------------------------------
 
-sub logger {
+sub pinto_class_for {
+    my ($self, $root) = @_;
+    return $root =~ m{^http://}x ? 'Pinto::Remote' : 'Pinto';
+}
+
+#------------------------------------------------------------------------------
+
+sub make_logger {
     my ($self, %options) = @_;
 
-    my $nocolor   = $options{nocolor};
-    my $colors    = $nocolor ? {} : ($self->log_colors);
+    my $no_color  = $options{no_color};
+    my $colors    = $no_color ? {} : ($self->log_colors);
     my $log_class = 'Log::Dispatch::Screen';
-    $log_class .= '::Color' unless $nocolor;
+    $log_class   .= '::Color' unless $no_color;
 
-    my $verbose = min($options{verbose} || 0, 2);
-
-    my $log_level = 2 - $verbose;      # Defaults to 'notice'
-    $log_level = 4 if $options{quiet}; # Only 'error' or higher
+    my $log_level = $options{log_level};
 
     return $log_class->new( min_level => $log_level,
                             color     => $colors,
@@ -93,13 +113,22 @@ sub default_log_colors { return $PINTO_DEFAULT_LOG_COLORS }
 
 #------------------------------------------------------------------------------
 
-sub pinto_class { return 'Pinto' }
+sub _prompt_for_password {
+   my ($self) = @_;
+
+   my $input    = Term::Prompt::prompt('p', 'Password:', '', '');
+   my $password = Encode::decode_utf8($input);
+   print "\n"; # Get on a new line
+
+   return $password;
+}
+
+#-------------------------------------------------------------------------------
 
-#------------------------------------------------------------------------------
 
 1;
 
-
+__END__
 
 =pod
 
@@ -113,14 +142,33 @@ App::Pinto - Command-line driver for Pinto
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
+
+=head1 DESCRIPTION
+
+App::Pinto is the command-line driver for Pinto.  It is just a
+front-end.  To do anything useful, you'll also need to install one of
+the back-ends, which ship separately.  If you need to create
+repositories and/or work directly with repositories on the local disk,
+then install L<Pinto>.  If you already have a repository on a remote
+host that is running L<pintod>, then install L<Pinto::Remote>.  If
+you're not sure what you need, then install L<Task::Pinto> to get the
+whole kit.
 
 =head1 METHODS
 
-=head2 pinto()
+=head2 pinto
 
-Returns a reference to a L<Pinto> object that has been constructed for
-this application.
+Returns a reference to a L<Pinto> or L<Pinto::Remote> object that has
+been constructed for this application.
+
+=head1 SEE ALSO
+
+L<Pinto::Manual> for general information on using Pinto.
+
+L<pinto> to create and manage a Pinto repository.
+
+L<pintod> to allow remote access to your Pinto repository.
 
 =head1 SUPPORT
 
@@ -202,6 +250,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
