@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,7 +23,9 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'description|d=s' => 'Brief description of the stack' ],
+        [ 'default'         => 'Make the new stack the default stack'  ],
+        [ 'description|d=s' => 'Brief description of the stack'        ],
+        [ 'lock'            => 'Lock the new stack to prevent changes' ],
     );
 
 
@@ -41,21 +43,6 @@ sub validate_args {
 
 #------------------------------------------------------------------------------
 
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    my $usage =  <<"END_USAGE";
-%c --root=REPOSITORY_ROOT $command [OPTIONS] FROM_STACK TO_STACK
-END_USAGE
-
-    chomp $usage;
-    return $usage;
-}
-
-#------------------------------------------------------------------------------
-
 sub execute {
     my ($self, $opts, $args) = @_;
 
@@ -68,7 +55,7 @@ sub execute {
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -80,11 +67,11 @@ App::Pinto::Command::copy - create a new stack by copying another
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT stack copy [OPTIONS] FROM_STACK TO_STACK
+  pinto --root=REPOSITORY_ROOT copy [OPTIONS] FROM_STACK TO_STACK
 
 =head1 DESCRIPTION
 
@@ -92,24 +79,37 @@ This command creates a new stack by copying an existing one.  All the
 pins and properties from the existing stack will also be copied to the
 new one.  The new stack must not already exist.
 
-Please see the L<new|App::Pinto::Command::new> command to
-create a new empty stack, or the
-L<edit|App::Pinto::Command::edit> command to change a stack's
-properties after it has been created.
+Use the L<new|App::Pinto::Command::new> command to create a new empty 
+stack, or the L<props|App::Pinto::Command::props> command to change 
+a stack's properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
 The two required arguments are the name of the source and target
-stacks.  Stack names must be alphanumeric (including "-" or "_") and
-will be forced to lowercase.
+stacks.  Stack names must be alphanumeric plus hyphens and underscores,
+and are not case-sensitive.
 
 =head1 COMMAND OPTIONS
 
 =over 4
 
+=item --default
+
+Also mark the new stack as the default stack.
+
 =item --description=TEXT
 
-Annotates the new stack with a brief description of its purpose.
+=item -d TEXT
+
+Use TEXT for the description of the stack.  If not specified, defaults
+to 'Copy of stack FROM_STACK'.
+
+=item --lock
+
+Also lock the new stack to prevent future changes.  This is useful for
+creating a read-only "tag" of a stack.  You can always use the
+L<lock|App::Pinto::Command::lock> or
+L<unlock|App::Pinto::Command::unlock> commands at a later time.
 
 =back
 
@@ -125,7 +125,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
