@@ -5,13 +5,15 @@ package App::Pinto::Command::list;
 use strict;
 use warnings;
 
+use Pinto::Util qw(interpolate);
+
 #-----------------------------------------------------------------------------
 
 use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -23,11 +25,12 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'distributions|D=s' => 'Limit to matching distribution paths' ],
+        [ 'author|A=s'        => 'Limit to distributions by author' ],
+        [ 'distributions|D=s' => 'Limit to matching distribution names' ],
         [ 'packages|P=s'      => 'Limit to matching package names' ],
         [ 'pinned!'           => 'Limit to pinned packages (negatable)' ],
         [ 'format=s'          => 'Format specification (See POD for details)' ],
-        [ 'stack|s=s'         => 'List a stack other than the default' ],
+        [ 'stack|s=s'         => 'List contents of this stack' ],
     );
 }
 
@@ -39,11 +42,10 @@ sub validate_args {
     $self->usage_error('Multiple arguments are not allowed')
         if @{ $args } > 1;
 
-    $self->usage_error('Cannot specify packages and distributions together')
-        if $opts->{packages} and $opts->{distributions};
+    $opts->{no_color} = $self->app->global_options->{no_color};
 
-    $opts->{format} = eval qq{"$opts->{format}"} ## no critic qw(StringyEval)
-        if $opts->{format};
+    $opts->{format} = interpolate( $opts->{format} )
+        if exists $opts->{format};
 
     $opts->{stack} = $args->[0]
         if $args->[0];
@@ -55,7 +57,7 @@ sub validate_args {
 
 1;
 
-
+__END__
 
 =pod
 
@@ -67,7 +69,7 @@ App::Pinto::Command::list - show the packages in a stack
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
@@ -76,13 +78,12 @@ version 0.040_02
 =head1 DESCRIPTION
 
 This command lists the distributions and packages that are registered
-to a stack within the repository.  You can format the output to see
-the specific bits of information that you want.
+on a stack.  You can format the output to see the specific bits of 
+information that you want.
 
-For a large repository, it can take fair amount of time to list
-everything.  You might consider using the C<--packages> or
-C<--distributions> options to narrow the scope.  If you need even more
-precise filtering, consider running the output through C<grep>.
+For a large repository, it can take a long time to list everything.
+So consider using the C<--packages> or C<--distributions> options
+to narrow the scope.  
 
 =head1 COMMAND ARGUMENTS
 
@@ -93,47 +94,53 @@ stack as an argument. So the following examples are equivalent:
   pinto --root REPOSITORY_ROOT list dev
 
 A stack specified as an argument in this fashion will override any
-stack specified with the C<--stack> option.
+stack specified with the C<--stack> option.  If a stack is not
+specified by neither argument nor option, then it defaults to the
+stack that is currently marked as the default stack.
 
 =head1 COMMAND OPTIONS
 
 =over 4
 
-=item -D=PATTERN
+=item --author AUTHOR
 
-=item --distributions=PATTERN
+=item -A AUTHOR
 
-Limit the listing to records where the distributions path matches
-C<PATTERN>.  Note that C<PATTERN> is just a plain string, not a regular
-expression.  The C<PATTERN> will match if it appears anywhere in the
-distribution path.
+Limit the listing to records where the distribution author is AUTHOR.
+Note this is an exact match, not a pattern match.  However, it is
+not case sensitive.
 
-=item --format=FORMAT_SPECIFICATION
+=item --distributions PATTERN
+
+=item -D PATTERN
+
+Limit the listing to records where the distribution archive name
+matches C<PATTERN>.  Note that C<PATTERN> is just a plain string, not
+a regular expression.  The C<PATTERN> will match if it appears
+anywhere in the distribution archive name.
+
+=item --format FORMAT_SPECIFICATION
 
 Format of the output using C<printf>-style placeholders.  Valid
 placeholders are:
 
   Placeholder    Meaning
   -----------------------------------------------------------------------------
-  %n             Package name
-  %N             Package name-version
+  %p             Package name
+  %P             Package name-version
   %v             Package version
-  %y             Pin status:                     (+) = is pinned
-  %m             Distribution maturity:          (d) = developer, (r) = release
-  %p             Distribution index path [1]
-  %P             Distribution physical path [2]
-  %s             Distribution origin:            (l) = local, (f) = foreign
-  %S             Distribution source repository
+  %y             Pin status:                     (!) = is pinned
   %a             Distribution author
+  %f             Distribution archive filename
+  %m             Distribution maturity:          (d) = developer, (r) = release
+  %h             Distribution index path [1]
+  %H             Distribution physical path [2]
+  %s             Distribution origin:            (l) = local,     (f) = foreign
+  %S             Distribution source
   %d             Distribution name
   %D             Distribution name-version
-  %w             Distribution version
+  %V             Distribution version
   %u             Distribution url
-  %k             Stack name
-  %e             Stack description
-  %M             Stack status                   (*) = is default
-  %U             Stack last-modified-time
-  %j             Stack last-modified-user
   %%             A literal '%'
 
 
@@ -144,14 +151,14 @@ placeholders are:
        and is relative to the root directory of the repository.
 
 You can also specify the minimum field widths and left or right
-justification, using the usual notation.  For example, this is what
-the default format looks like.
+justification, using the usual notation.  For example, the default
+format looks something like this:
 
-  %m%s %-38n %v %p\n
+  %m%s %-38n %12v %a/%f\n
 
-=item -P=PATTERN
+=item --packages PATTERN
 
-=item --packages=PATTERN
+=item -P PATTERN
 
 Limit the listing to records where the package name matches
 C<PATTERN>.  Note that C<PATTERN> is just a plain string, not a
@@ -162,17 +169,15 @@ in the package name.
 
 Limit the listing to records for packages that are pinned.
 
-=item --stack=NAME
+=item --stack NAME
+
+=item -s NAME
 
 List the contents of the stack with the given NAME.  Defaults to the
 name of whichever stack is currently marked as the default stack.  Use
-the L<stacks|App::Pinto::Command::stack> command to see the
+the L<stacks|App::Pinto::Command::stacks> command to see the
 stacks in the repository.
 
-If the stack name is "@" then the contents of all stacks will be
-listed.  And unless an explicit C<--format> was given, the listing
-will include the name of the stack on each record.
-
 =back
 
 =head1 AUTHOR
@@ -187,7 +192,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
