@@ -11,7 +11,7 @@ use base qw(App::Pinto::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -19,16 +19,6 @@ sub command_names { return qw( manual man --man ) }
 
 #-----------------------------------------------------------------------------
 
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    return "%c $command COMMAND"
-}
-
-#-------------------------------------------------------------------------------
-
 sub validate_args {
     my ($self, $opts, $args) = @_;
 
@@ -60,8 +50,8 @@ sub execute {
 #-------------------------------------------------------------------------------
 1;
 
-
 __END__
+
 =pod
 
 =for :stopwords Jeffrey Thalhammer Imaginative Software Systems
@@ -72,7 +62,7 @@ App::Pinto::Command::manual - show the full manual for a command
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 AUTHOR
 
@@ -86,4 +76,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
