@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -19,10 +19,9 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'description|d=s' => 'Brief description of the stack' ],
+        [ 'default'               => 'Make the new stack the default stack' ],
+        [ 'description|d=s'       => 'Brief description of the stack'       ],
     );
-
-
 }
 
 #------------------------------------------------------------------------------
@@ -33,39 +32,15 @@ sub validate_args {
     $self->usage_error('Must specify exactly one stack')
         if @{$args} != 1;
 
+    $opts->{stack} = $args->[0];
+
     return 1;
 }
 
-#------------------------------------------------------------------------------
-
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    my $usage =  <<"END_USAGE";
-%c --root=REPOSITORY_ROOT $command [OPTIONS] STACK
-END_USAGE
-
-    chomp $usage;
-    return $usage;
-}
-
-#------------------------------------------------------------------------------
-
-sub execute {
-    my ($self, $opts, $args) = @_;
-
-    my $result = $self->pinto->run($self->action_name, %{$opts},
-                                                       stack => $args->[0]);
-
-    return $result->exit_status;
-}
-
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -77,34 +52,39 @@ App::Pinto::Command::new - create a new empty stack
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
-  pinto --root=REPOSITORY_ROOT stack create [OPTIONS] STACK
+  pinto --root=REPOSITORY_ROOT new [OPTIONS] STACK
 
 =head1 DESCRIPTION
 
 This command creates a new empty stack.
 
-Please see the L<copy|App::Pinto::Command::copy> command to
-create a new stack from another one, or the
-L<edit:App::Pinto::Command::copy> command to change a
-stack's properties after it has been created.
+See the L<copy|App::Pinto::Command::copy> command to create a new 
+stack from another one, or the L<props|App::Pinto::Command::props> 
+command to change a stack's properties after it has been created.
 
 =head1 COMMAND ARGUMENTS
 
 The required argument is the name of the stack you wish to create.
-Stack names must be alphanumeric (including "-" or "_") and will be
-forced to lowercase.
+Stack names must be alphanumeric plus hyphens and underscores, and
+are not case sensitive.
 
 =head1 COMMAND OPTIONS
 
 =over 4
 
+=item --default
+
+Also mark the new stack as the default stack.
+
 =item --description=TEXT
 
-Annotates this stack with a description of its purpose.
+=item -d TEXT
+
+Use TEXT for the description of the stack.
 
 =back
 
@@ -120,8 +100,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
