@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
@@ -39,7 +39,7 @@ sub validate_args {
 #------------------------------------------------------------------------------
 1;
 
-
+__END__
 
 =pod
 
@@ -51,7 +51,7 @@ App::Pinto::Command::nop - initialize Pinto and exit
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
@@ -59,7 +59,7 @@ version 0.040_02
 
 =head1 DESCRIPTION
 
-This command is a no-operation.  It locks and initializes the
+This command is a no-operation.  It puts a shared lock on the
 repository, but does not perform any operations.  This is really only
 used for diagnostic purposes.  So don't worry about it too much.
 
@@ -71,10 +71,9 @@ None.
 
 =over 4
 
-=item --sleep=N
+=item --sleep N
 
-Directs L<Pinto> to sleep for N seconds before releasing the lock and
-exiting.  Default is 0.
+Sleep for N seconds before releasing the lock and exiting.  Default is 0.
 
 =back
 
@@ -90,7 +89,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
