@@ -1,7 +1,7 @@
-package App::Pinto::Command::statistics;
-
 # ABSTRACT: report statistics about the repository
 
+package App::Pinto::Command::statistics;
+
 use strict;
 use warnings;
 
@@ -11,33 +11,16 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #------------------------------------------------------------------------------
 
 sub command_names { return qw( statistics stats ) }
 
 #------------------------------------------------------------------------------
-
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
- my $usage =  <<"END_USAGE";
-%c --root=REPOSITORY_ROOT $command
-END_USAGE
-
-    chomp $usage;
-    return $usage;
-}
-
-
-#------------------------------------------------------------------------------
-
 1;
 
-
+__END__
 
 =pod
 
@@ -49,7 +32,7 @@ App::Pinto::Command::statistics - report statistics about the repository
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
@@ -57,8 +40,9 @@ version 0.040_02
 
 =head1 DESCRIPTION
 
-This command reports some statistics about the repository.  It is
-currently only reports information about the default stack.
+!! THIS COMMAND IS EXPERIMENTAL !!
+
+This command reports some statistics about the repository.
 
 =head1 COMMAND ARGUMENTS
 
@@ -80,7 +64,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
