@@ -11,7 +11,7 @@ use base 'App::Pinto::Command';
 
 #------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
+our $VERSION = '0.065_01'; # VERSION
 
 #-----------------------------------------------------------------------------
 
@@ -19,28 +19,15 @@ sub opt_spec {
     my ($self, $app) = @_;
 
     return (
-        [ 'stack|s=s' => 'Stack from which to unpin the target' ],
+        [ 'dry-run'     => 'Do not commit any changes'            ],
+        [ 'message|m=s' => 'Message to describe the change'       ],
+        [ 'stack|s=s'   => 'Unpin targets from this stack'        ],
+        [ 'use-default-message|M' => 'Use the generated message'  ],
     );
 }
 
 #------------------------------------------------------------------------------
 
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    my $usage =  <<"END_USAGE";
-%c --root=REPOSITORY_ROOT $command [OPTIONS] TARGET ...
-%c --root=REPOSITORY_ROOT $command [OPTIONS] < LIST_OF_TARGETS
-END_USAGE
-
-    chomp $usage;
-    return $usage;
-}
-
-#------------------------------------------------------------------------------
-
 sub args_attribute { return 'targets' }
 
 #------------------------------------------------------------------------------
@@ -51,7 +38,7 @@ sub args_from_stdin { return 1 }
 
 1;
 
-
+__END__
 
 =pod
 
@@ -63,12 +50,11 @@ App::Pinto::Command::unpin - free packages that have been pinned
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 SYNOPSIS
 
   pinto --root=REPOSITORY_ROOT unpin [OPTIONS] TARGET ...
-  pinto --root=REPOSITORY_ROOT unpin [OPTIONS] < LIST_OF_TARGETS
 
 =head1 DESCRIPTION
 
@@ -89,7 +75,7 @@ specified as packages or distributions, such as:
 
 When unpinning a distribution, all the packages in that distribution
 become unpinned.  Likewise when unpinning a package, all its sister
-packages in the same distributon also become unpinned.
+packages in the same distribution also become unpinned.
 
 You can also pipe arguments to this command over STDIN.  In that case,
 blank lines and lines that look like comments (i.e. starting with "#"
@@ -99,6 +85,24 @@ or ';') will be ignored.
 
 =over 4
 
+=item --dry-run
+
+Go through all the motions, but do not actually commit any changes to
+the repository.  Use this option to see how the command would
+potentially impact the stack.
+
+=item --message=TEXT
+
+=item -m TEXT
+
+Use TEXT as the revision history log message.  If you do not use the
+C<--message> option or the C<--use-default-message> option, then you
+will be prompted to enter the message via your text editor.  Use the
+C<EDITOR> or C<VISUAL> environment variables to control which editor
+is used.  A log message is not required whenever the C<--dry-run>
+option is set, or if the action did not yield any changes to the
+repository.
+
 =item --stack=NAME
 
 Unpins the package on the stack with the given NAME.  Defaults to the
@@ -106,6 +110,15 @@ name of whichever stack is currently marked as the default stack.  Use
 the L<stacks|App::Pinto::Command::stacks> command to see your
 stacks.
 
+=item --use-default-message
+
+=item -M
+
+Use the default value for the revision history log message.  Pinto
+will generate a semi-informative log message just based on the command
+and its arguments.  If you set an explicit message with C<--message>,
+the C<--use-default-message> option will be silently ignored.
+
 =back
 
 =head1 AUTHOR
@@ -120,8 +133,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
-
