@@ -11,17 +11,7 @@ use base qw(App::Pinto::Command);
 
 #-------------------------------------------------------------------------------
 
-our $VERSION = '0.040_02'; # VERSION
-
-#-------------------------------------------------------------------------------
-
-sub usage_desc {
-    my ($self) = @_;
-
-    my ($command) = $self->command_names();
-
-    return "%c $command"
-}
+our $VERSION = '0.065_01'; # VERSION
 
 #-------------------------------------------------------------------------------
 
@@ -29,13 +19,14 @@ sub execute {
     my ($self, $opts, $args) = @_;
 
     my $app_class = ref $self->app();
-    my $app_version = $self->app->VERSION();
-    printf "$app_class $app_version\n";
+    my $app_version = $self->app->VERSION || '?';
+    print "$app_class $app_version\n";
 
-    my $pinto_class = $self->app->pinto_class();
-    Class::Load::load_class( $pinto_class );
-    my $pinto_version = $pinto_class->VERSION();
-    printf "$pinto_class $pinto_version\n";
+    for my $pinto_class ( qw(Pinto Pinto::Remote) ) {
+        Class::Load::try_load_class( $pinto_class ) or next;
+        my $pinto_version = $pinto_class->VERSION || '?';
+        print "$pinto_class $pinto_version\n";
+    }
 
     return 0;
 }
@@ -45,8 +36,8 @@ sub execute {
 
 1;
 
-
 __END__
+
 =pod
 
 =for :stopwords Jeffrey Thalhammer Imaginative Software Systems
@@ -57,7 +48,7 @@ App::Pinto::Command::version - show version information
 
 =head1 VERSION
 
-version 0.040_02
+version 0.065_01
 
 =head1 DESCRIPTION
 
@@ -75,4 +66,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
